pub struct LlmEventSummarizer { /* private fields */ }Expand description
An LLM-based event summarizer for sliding window compaction.
When called with a list of events, this formats the events, generates a
summary using an LLM, and returns a new Event containing the summary
within an EventCompaction.
Implementations